Grano
=====

``grano`` is a social network analysis tool for data-driven news applications. It provides components needed to build domain-specific social network applications. For example, it can be used to track the relations between people, institutions and companies expressed through financial flows and other interactions.

Grano is currently developed as a backend to `openinterests.eu <http://openinterests.eu>`_ and `nomenklatura <http://nomenklatura.pudo.org>`_.

Documentation for grano is available at `docs.grano.cc <http://docs.grano.cc>`_, including: 

* `Installation instructions <http://granoproject.org/docs/install/>`_
* `Technical introduction <http://granoproject.org/docs/>`_
* `Web (REST) API <http://granoproject.org/docs/api/>`_

``grano`` is also available on cheeseshop, and can be installed with::

    pip install grano
